ChartComponent

Struct ChartComponent 

pub struct ChartComponent { /* private fields */ }
Chart rendering component with comprehensive chart type support

Implementations

Source

impl ChartComponent

pub fn new(id: String) -> Self

Create a new ChartComponent with default configuration

pub fn with_config(id: String, config: ChartConfig) -> Self

Create a ChartComponent with custom configuration

pub fn with_data_and_config( id: String, data: Vec<DataPoint>, config: ChartConfig, ) -> Self

Create a ChartComponent with data and configuration

pub fn set_data(&mut self, data: Vec<DataPoint>)

Set chart data

pub fn get_data(&self) -> &[DataPoint]

Get chart data reference

pub fn set_config(&mut self, config: ChartConfig)

Set chart configuration

pub fn get_config(&self) -> &ChartConfig

Get chart configuration reference

pub fn parse_data_from_content(&mut self, content: &str)

Parse chart data from text content

pub fn generate(&self) -> String

Generate chart content as string (for legacy compatibility)

pub fn generate_with_muxbox_title(&self, muxbox_title: Option<&str>) -> String

Generate chart content with muxbox title context to avoid duplication

pub fn render(&self, bounds: &Bounds, buffer: &mut ScreenBuffer)

Render chart directly to screen buffer at specified bounds

pub fn render_with_colors( &self, bounds: &Bounds, fg_color: &str, bg_color: &str, buffer: &mut ScreenBuffer, )

Render chart with custom colors

pub fn parse_chart_data(content: &str) -> Vec<DataPoint>

Parse chart data from text content (static version for external use)