pub struct SelectionStyleRenderer {
pub id: String,
pub config: SelectionStyleConfig,
}Expand description
Enhanced selection styling component
Fields
id: Stringconfig: SelectionStyleConfigImplementations
Sourceimpl SelectionStyleRenderer
impl SelectionStyleRenderer
Sourcepub fn new(id: String, config: SelectionStyleConfig) -> Self
pub fn new(id: String, config: SelectionStyleConfig) -> Self
Create new selection style renderer with configuration
Sourcepub fn with_defaults(id: String) -> Self
pub fn with_defaults(id: String) -> Self
Create with default configuration
Sourcepub fn render_choice(
&self,
choice: &Choice,
bounds: &Bounds,
y_position: usize,
x_position: usize,
base_fg_color: &Option<String>,
base_bg_color: &Option<String>,
selected_fg_color: &Option<String>,
selected_bg_color: &Option<String>,
is_focused: bool,
buffer: &mut ScreenBuffer,
)
pub fn render_choice( &self, choice: &Choice, bounds: &Bounds, y_position: usize, x_position: usize, base_fg_color: &Option<String>, base_bg_color: &Option<String>, selected_fg_color: &Option<String>, selected_bg_color: &Option<String>, is_focused: bool, buffer: &mut ScreenBuffer, )
Render choice with enhanced selection styling
Sourcepub fn calculate_style_colors_and_text(
&self,
choice: &Choice,
base_fg_color: &Option<String>,
base_bg_color: &Option<String>,
selected_fg_color: &Option<String>,
selected_bg_color: &Option<String>,
is_focused: bool,
) -> (Option<String>, Option<String>, String)
pub fn calculate_style_colors_and_text( &self, choice: &Choice, base_fg_color: &Option<String>, base_bg_color: &Option<String>, selected_fg_color: &Option<String>, selected_bg_color: &Option<String>, is_focused: bool, ) -> (Option<String>, Option<String>, String)
Calculate final colors and text based on style configuration
Sourcepub fn get_legacy_style_config() -> SelectionStyleConfig
pub fn get_legacy_style_config() -> SelectionStyleConfig
Get default selection style for migration from existing choice renderer