TabBar

Struct TabBar 

pub struct TabBar;
Tab bar component for displaying stream tabs with scrolling support

Implementations

Source

impl TabBar

pub fn draw( y: usize, x1: usize, x2: usize, fg_color: &Option<String>, bg_color: &Option<String>, title_fg_color: &Option<String>, title_bg_color: &Option<String>, tab_labels: &[String], tab_close_buttons: &[bool], active_tab_index: usize, box_selected: bool, tab_scroll_offset: usize, hovered_target: Option<&TabHoverTarget>, buffer: &mut ScreenBuffer, )

Draw tab bar with all functionality preserved from original implementation

pub fn calculate_tab_click_index( click_x: usize, x1: usize, x2: usize, tab_labels: &[String], tab_scroll_offset: usize, fg_color: &Option<String>, bg_color: &Option<String>, ) -> Option<usize>

Calculate which tab was clicked based on mouse position

pub fn calculate_tab_navigation_click( click_x: usize, x1: usize, x2: usize, tab_labels: &[String], tab_scroll_offset: usize, fg_color: &Option<String>, bg_color: &Option<String>, ) -> Option<TabNavigationAction>

Calculate if click was on navigation arrows

pub fn calculate_tab_close_click( click_x: usize, x1: usize, x2: usize, tab_labels: &[String], tab_close_buttons: &[bool], tab_scroll_offset: usize, fg_color: &Option<String>, bg_color: &Option<String>, ) -> Option<usize>

Calculate if click was on a close button within a tab

pub fn calculate_tab_hit_target( x: usize, x1: usize, x2: usize, tab_labels: &[String], tab_close_buttons: &[bool], tab_scroll_offset: usize, fg_color: &Option<String>, bg_color: &Option<String>, ) -> Option<TabHitTarget>

pub fn calculate_tab_hover_target( hover_x: usize, x1: usize, x2: usize, tab_labels: &[String], tab_close_buttons: &[bool], tab_scroll_offset: usize, fg_color: &Option<String>, bg_color: &Option<String>, ) -> Option<TabHoverTarget>