pub enum StreamSource {
StaticContent(StaticContentSource),
ChoiceExecution(ChoiceExecutionSource),
PeriodicRefresh(PeriodicRefreshSource),
PTY(PTYSource),
Redirect(RedirectSource),
Socket(SocketSource),
ImmediateExecution(ImmediateExecutionSource),
ThreadPoolExecution(ThreadPoolExecutionSource),
PtySessionExecution(PtySessionExecutionSource),
}Variants
StaticContent(StaticContentSource)
ChoiceExecution(ChoiceExecutionSource)
PeriodicRefresh(PeriodicRefreshSource)
PTY(PTYSource)
Redirect(RedirectSource)
Socket(SocketSource)
ImmediateExecution(ImmediateExecutionSource)
ThreadPoolExecution(ThreadPoolExecutionSource)
PtySessionExecution(PtySessionExecutionSource)
Implementations
Sourceimpl StreamSource
impl StreamSource
Sourcepub fn create_immediate_execution_source(
choice_id: String,
muxbox_id: String,
script: Vec<String>,
) -> Self
pub fn create_immediate_execution_source( choice_id: String, muxbox_id: String, script: Vec<String>, ) -> Self
Create an immediate execution source for synchronous UI thread execution
Sourcepub fn create_thread_pool_execution_source(
choice_id: String,
muxbox_id: String,
script: Vec<String>,
thread_id: Option<String>,
timeout_seconds: Option<u32>,
) -> Self
pub fn create_thread_pool_execution_source( choice_id: String, muxbox_id: String, script: Vec<String>, thread_id: Option<String>, timeout_seconds: Option<u32>, ) -> Self
Create a thread pool execution source for background thread execution
Sourcepub fn create_pty_session_execution_source(
choice_id: String,
muxbox_id: String,
command: String,
args: Vec<String>,
working_dir: Option<String>,
terminal_size: (u16, u16),
) -> Self
pub fn create_pty_session_execution_source( choice_id: String, muxbox_id: String, command: String, args: Vec<String>, working_dir: Option<String>, terminal_size: (u16, u16), ) -> Self
Create a PTY session execution source for real-time process execution
Sourcepub fn from_execution_mode(
execution_mode: &ExecutionMode,
choice_id: String,
muxbox_id: String,
script: Vec<String>,
additional_params: Option<HashMap<String, String>>,
) -> Self
pub fn from_execution_mode( execution_mode: &ExecutionMode, choice_id: String, muxbox_id: String, script: Vec<String>, additional_params: Option<HashMap<String, String>>, ) -> Self
Convert ExecutionMode to the appropriate source type
Sourcepub fn supports_immediate_source(&self) -> bool
pub fn supports_immediate_source(&self) -> bool
Check if this source supports a specific execution mode trait
pub fn supports_thread_pool_source(&self) -> bool
pub fn supports_pty_session_source(&self) -> bool
Sourcepub fn as_immediate_source(&self) -> Option<&dyn ImmediateSource>
pub fn as_immediate_source(&self) -> Option<&dyn ImmediateSource>
Get execution mode-specific source as trait object
pub fn as_thread_pool_source(&self) -> Option<&dyn ThreadPoolSource>
pub fn as_pty_session_source(&self) -> Option<&dyn PtySessionSource>