Chart Component System - Unified chart rendering component with multiple chart types
This module provides a comprehensive chart rendering component that encapsulates all chart generation logic while providing a clean, reusable interface.
Structs
- Chart
Component - Chart rendering component with comprehensive chart type support
- Chart
Config - Chart configuration
- Data
Point - Chart data point
Enums
- Chart
Type - Supported chart types